@@ -20,10 +20,10 @@
 #
 .onLoad <- function(libname, pkgname) {
 	.jpackage(pkgname, lib.loc = libname)
-	jv <- .jcall("java/lang/System", "S", "getProperty", "java.runtime.version") 
-	if(substr(jv, 1L, 2L) == "1.") {
-		jvn <- as.numeric(paste0(strsplit(jv, "[.]")[[1L]][1:2], collapse = "."))
-		if(jvn < 1.6) stop(paste("Java 6 is needed for this package but rJava is linked to Java ", jvn))
-	}
+	#jv <- .jcall("java/lang/System", "S", "getProperty", "java.runtime.version") 
+	#if(substr(jv, 1L, 1L) == "1") {
+	#	jvn <- as.numeric(paste0(strsplit(jv, "[.]")[[1L]][1:2], collapse = "."))
+	#	if(jvn < 1.7) stop(paste("Java 7 is needed for this package but rJava is linked to Java ", jvn))
+	#}
 	
 }
